@@ -33,15 +33,15 @@
 //! # Cargo.toml
 //!
 //! [dependencies]
-//! windmark = "0.1.9"
+//! windmark = "0.1.11"
 //! tokio = { version = "0.2.4", features = ["full"] }
 //!
 //! # If you would like to use the built-in logger (recommended)
-//! # windmark = { version = "0.1.9", features = ["logger"] }
+//! # windmark = { version = "0.1.11", features = ["logger"] }
 //!
 //! # If you would like to use the built-in MIME dedection when `Success`-ing a file
 //! # (recommended)
-//! # windmark = { version = "0.1.9", features = ["auto-deduce-mime"] }
+//! # windmark = { version = "0.1.11", features = ["auto-deduce-mime"] }
 //! ```
 //!
 //! ### Implement a Windmark server
@@ -70,6 +70,11 @@
 //! Examples can be found within the
 //! [`examples/`](https://github.com/gemrest/windmark/tree/main/examples) directory.
 //!
+//! An example of a fully featured Gemini capsule written using Windmark can be
+//! found [here](https://github.com/gemrest/locus). This example Gemini capsule also
+//! happens to be the source code for [Fuwn's](https://github.com/Fuwn) (this
+//! library's author) personal Gemini capsule!
+//!
 //! ## Modules
 //!
 //! Modules are reusable extensions which can be procedurally mounted onto
@@ -151,6 +156,7 @@ pub struct Router {
   language:              String,
   port:                  i32,
   modules:               Arc<Mutex<Vec<Box<dyn Module + Send>>>>,
+  fix_path:              bool,
 }
 impl Router {
   /// Create a new `Router`
@@ -356,7 +362,15 @@ impl Router {
       }
     }
 
-    let route = &mut self.routes.at(url.path());
+    let fixed_path = if self.fix_path {
+      self
+        .routes
+        .fix_path(url.path())
+        .unwrap_or_else(|| url.path().to_string())
+    } else {
+      url.path().to_string()
+    };
+    let route = &mut self.routes.at(&fixed_path);
 
     for module in &mut *self.modules.lock().unwrap() {
       module.on_pre_route(CallbackContext::new(stream.get_ref(), &url, {
@@ -782,6 +796,20 @@ impl Router {
 
     self
   }
+
+  /// Performs a case-insensitive lookup of routes, using the case corrected
+  /// path if successful. Missing/ extra trailing slashes are also corrected.
+  ///
+  /// # Examples
+  ///
+  /// ```rust
+  /// windmark::Router::new().set_fix_path(true); 
+  /// ```
+  pub fn set_fix_path(&mut self, fix_path: bool) -> &mut Self {
+    self.fix_path = fix_path;
+
+    self
+  }
 }
 impl Default for Router {
   fn default() -> Self {
@@ -809,6 +837,7 @@ impl Default for Router {
       language: "en".to_string(),
       port: 1965,
       modules: Arc::new(Mutex::new(vec![])),
+      fix_path: false,
     }
   }
 }
